package de.opalpiraten.scenepainter.gui;
import java.util.*;
import java.io.*;
import java.net.*;
import java.awt.*;
import java.awt.event.*;
import java.awt.dnd.*;
import javax.swing.text.*;
import javax.swing.text.html.*;
import javax.swing.*;
import javax.swing.event.*;
import de.opalpiraten.scenepainter.sys.*; 
import de.opalpiraten.scenepainter.gui.render.*;

/**
 * A Window, that will find a HTML page associated with an object and
 * display it.
 */
public class HelpBrowser extends JInternalFrame implements HyperlinkListener,
KeyListener {

  private JEditorPane content;
  
  /**
   * Construct a new Helpbrowser
   * @param obj the object for which to search a help page
   */
  public HelpBrowser(Object obj) {
    super(Dict.get("gui.helpbrowser.title"),true,true,true,true);
    try {
      content = new JEditorPane("text/html","");
      content.addKeyListener(this);
      addKeyListener(this);
      content.setEditable(false);
      content.addHyperlinkListener(this);
      URL base = getURLforObject(obj);
      HTMLDocument doc = (HTMLDocument)content.getDocument();
      HTMLEditorKit kit = (HTMLEditorKit)content.getEditorKit();
      kit.read(base.openStream(),doc,0);
      doc.setBase(new URL("file","",base.getPath()));

      getContentPane().add(new JScrollPane(content));
      
    }
    catch (Exception e) {
      content = new JEditorPane();
      content.setText(Dict.get("gui.helpbrowser.unavailable"));
      content.setEditable(false);
      e.printStackTrace();
    }
    add(new JScrollPane(content));
    content.setCaretPosition(0);
  }
  
  private URL getURLforObject(Object o) {
    String clazz = o.getClass().getName().toLowerCase().replaceAll("\\.","_");
    String path = "resources/help/"+Locale.getDefault().getLanguage()+"/"+clazz+"/index.html";
    try {
      URL u = o.getClass().getClassLoader().getResource(path);
      u.openStream();
      return u;
    }
    catch (Exception e) {
      // e.printStackTrace();
      // No help for the current locale, try the default
      System.err.println("Unavailable: "+path);
    }
    path = "resources/help/en/"+clazz+"/index.html";
    return o.getClass().getClassLoader().getResource(path);
  }
  
  public void hyperlinkUpdate(HyperlinkEvent e) { 
    try {
      if (e.getEventType().equals(HyperlinkEvent.EventType.ACTIVATED)) {
        content.setPage(e.getURL());
      }
    }
    catch (Exception exp) {
    }
  }
  
  public void keyPressed(KeyEvent e) {}
  public void keyReleased(KeyEvent e) {
    if (e.getKeyCode() == KeyEvent.VK_ESCAPE) {
      dispose();
    }
  }
  public void keyTyped(KeyEvent e) {}
}
